@@ -62,8 +62,10 @@ def translate_file(config, target_file, SOURCE_LANG, DEST_LANG):
 
     # result = lib_inst.davidgu.polycode['@dev'](source, config, map)
 
+    fextension = os.path.splitext(target_file)[1]
+
     payload = {'doc': source, 'from': SOURCE_LANG, 
-        'to': DEST_LANG, 'map': json.dumps(map)}
+        'to': DEST_LANG, 'map': json.dumps(map), 'ext':fextension}
     # print(payload)
     req = requests.get(SERVER_URL, params=payload)
     # print(req.url)
@@ -130,7 +132,7 @@ def translate_all(config, DEST_LANG, additional_ignores=[]):
 
     for file in target_files:
         if os.path.splitext(file)[-1] in TARGET_FILE_EXTENSIONS:
-            # translate_file(config, file, SOURCE_LANG, DEST_LANG)
+            translate_file(config, file, SOURCE_LANG, DEST_LANG)
             print(file)
 
     with open(TRANSLATE_TEMP_FILENAME, 'r+') as f:
@@ -174,6 +176,10 @@ def main():
         type=str, help='Translate a single file instead of the whole project')
     parser.add_argument('-l', '--language', type=str,
         help='Specify the language to translate to.')
+    parser.add_argument('-w', '--word', type=str, 
+        help='Define a word to define or get a definition of.')
+    parser.add_argument('-d', '--definition', type=str, 
+        help='The new value of the specified word.')
     args = parser.parse_args()
 
     if args.command == 'translate':
@@ -345,10 +351,12 @@ def main():
         # Doesn't handle invalid args
         word = args.word
         definition = args.definition
+        file = args.single_file
         from_lang = config['source_lang']
         to_lang = args.language if args.language else pconfig['output_lang']
 
-        dictionary_path = 'test_dictionary.json'  # Fix this
+        map_file_path = TRANSLATE_DICT_FILES_PATH + '{}.map'.format(file)
+        dictionary_path = map_file_path
         json_data = json.loads(open(dictionary_path).read())
         dictionary = json_data['tokens']
         languages = json_data['languages']
@@ -374,10 +382,12 @@ def main():
 
     if args.command == 'definition':
         word = args.word
+        file = args.single_file
         from_lang = config['source_lang']
         to_lang = args.language if args.language else pconfig['output_lang']
 
-        dictionary_path = 'test_dictionary.json'  # Fix this
+        map_file_path = TRANSLATE_DICT_FILES_PATH + '{}.map'.format(file)
+        dictionary_path = map_file_path
         json_data = json.loads(open(dictionary_path).read())
         dictionary = json_data['tokens']
         languages = json_data['languages']
